#!/usr/bin/env python
# -*- coding: utf-8 -*-


import os
import sys
sys.path.insert(0, os.path.abspath('../'))

if sys.version_info < (3,):
    reload(sys)
    sys.setdefaultencoding('utf-8')
